@@ -1,62 +1,80 @@
-from emannotationschemas.schemas.synapse import SynapseSchema
-from emannotationschemas.schemas.synapse import PlasticSynapse
-from emannotationschemas.schemas.synapse import ValidSynapse
-from emannotationschemas.schemas.synapse import BuhmannSynapseSchema
-from emannotationschemas.schemas.synapse import BuhmannEcksteinSynapseSchema
-from emannotationschemas.schemas.synapse import NoCleftSynapse
+from emannotationschemas.errors import UnknownAnnotationTypeException
+from emannotationschemas.flatten import create_flattened_schema
+from emannotationschemas.schemas.base import (
+    FlatSegmentationReferenceSinglePoint,
+    ReferenceAnnotation,
+    ReferenceInteger,
+    ReferenceTagAnnotation,
+    ReferenceTagWithConfidence,
+    RepresentativePoint,
+)
+from emannotationschemas.schemas.bound_bool_tag import (
+    BoundBoolAnnotation,
+    BoundBoolWithValid,
+    BoundTagWithValid,
+    SpatialPointBoolWithValid,
+)
+from emannotationschemas.schemas.bound_text_tag import (
+    Bound2TagAnnotation,
+    Bound2TagAnnotationUser,
+    BoundDoubleTagAnnotation,
+    BoundDoubleTagAnnotationUser,
+    BoundTagAnnotation,
+    BoundTagAnnotationUser,
+)
 from emannotationschemas.schemas.bouton_shape import BoutonShape
-from emannotationschemas.schemas.presynaptic_bouton_type import PresynapticBoutonType
-from emannotationschemas.schemas.base import ReferenceAnnotation, ReferenceTagAnnotation
+from emannotationschemas.schemas.braincircuits import (
+    BrainCircuitsBoundTagAnnotationUser,
+)
+from emannotationschemas.schemas.cell_type_local import CellTypeLocal, CellTypeReference
+from emannotationschemas.schemas.contact import Contact
+from emannotationschemas.schemas.derived_spatial_point import (
+    DerivedNumeric,
+    DerivedSpatialPoint,
+    DerivedTag,
+)
+from emannotationschemas.schemas.extended_classical_cell_type import (
+    ExtendedClassicalCellType,
+)
+from emannotationschemas.schemas.fly_cell_types import FlyCellType, FlyCellTypeExt
 from emannotationschemas.schemas.functional_coregistration import (
     FunctionalCoregistration,
     FunctionalUnitCoregistration,
     FunctionalUnitCoregistrationExtended,
+    V1DDFunctionalUnitCoregistration,
 )
-from emannotationschemas.schemas.postsynaptic_compartment import PostsynapticCompartment
-from emannotationschemas.schemas.base import (
-    FlatSegmentationReferenceSinglePoint,
-    RepresentativePoint,
-)
-from emannotationschemas.schemas.cell_type_local import CellTypeLocal, CellTypeReference
-from emannotationschemas.schemas.bound_text_tag import (
-    BoundTagAnnotation,
-    BoundDoubleTagAnnotation,
-    Bound2TagAnnotation,
-    BoundTagAnnotationUser,
-    BoundDoubleTagAnnotationUser,
-    Bound2TagAnnotationUser,
-)
+from emannotationschemas.schemas.functional_props import FunctionalPropertiesBCM
 from emannotationschemas.schemas.glia_contact import GliaContact
-from emannotationschemas.schemas.contact import Contact
-from emannotationschemas.schemas.extended_classical_cell_type import (
-    ExtendedClassicalCellType,
-)
+from emannotationschemas.schemas.groups import SimpleGroup
+from emannotationschemas.schemas.neuropil import FlyNeuropil
 from emannotationschemas.schemas.nucleus_detection import NucleusDetection
-from emannotationschemas.schemas.derived_spatial_point import (
-    DerivedSpatialPoint,
-    DerivedTag,
-    DerivedNumeric,
-)
+from emannotationschemas.schemas.postsynaptic_compartment import PostsynapticCompartment
+from emannotationschemas.schemas.presynaptic_bouton_type import PresynapticBoutonType
 from emannotationschemas.schemas.proofreading import (
     CompartmentProofreadStatus,
-    ProofreadStatus,
+    CompartmentProofreadStatusStrategy,
     ProofreadingBoolStatusUser,
+    ProofreadStatus,
 )
-from emannotationschemas.schemas.neuropil import FlyNeuropil
-from emannotationschemas.schemas.groups import SimpleGroup
-from emannotationschemas.schemas.fly_cell_types import FlyCellType, FlyCellTypeExt
-from emannotationschemas.schemas.braincircuits import (
-    BrainCircuitsBoundTagAnnotationUser,
+from emannotationschemas.schemas.reference_text_float import (
+    ReferenceTagFloat,
+)
+from emannotationschemas.schemas.synapse import (
+    BuhmannEcksteinSynapseSchema,
+    BuhmannSynapseSchema,
+    NoCenterSynapse,
+    NoCleftSynapse,
+    PlasticSynapse,
+    SynapseSchema,
+    ValidSynapse,
 )
 
-from emannotationschemas.errors import UnknownAnnotationTypeException
-from emannotationschemas.flatten import create_flattened_schema
-
-__version__ = "5.8.0"
+__version__ = "5.23.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
     "nocleft_synapse": NoCleftSynapse,
+    "nocenter_synapse": NoCenterSynapse,
     "fly_synapse": BuhmannSynapseSchema,
     "fly_nt_synapse": BuhmannEcksteinSynapseSchema,
     "bouton_shape": BoutonShape,
@@ -64,7 +82,9 @@ type_mapping = {
     "postsynaptic_compartment": PostsynapticCompartment,
     "microns_func_coreg": FunctionalCoregistration,
     "microns_func_unit_coreg": FunctionalUnitCoregistration,
+    "v1dd_func_unit_coreg": V1DDFunctionalUnitCoregistration,
     "func_unit_ext_coreg": FunctionalUnitCoregistrationExtended,
+    "func_properties_bcm": FunctionalPropertiesBCM,
     "simple_reference": ReferenceAnnotation,
     "reference_tag": ReferenceTagAnnotation,
     "cell_type_local": CellTypeLocal,
@@ -94,6 +114,14 @@ type_mapping = {
     "fly_cell_type": FlyCellType,
     "fly_cell_type_ext": FlyCellTypeExt,
     "braincircuits_annotation_user": BrainCircuitsBoundTagAnnotationUser,
+    "bound_tag_bool": BoundBoolAnnotation,
+    "bound_tag_bool_valid": BoundBoolWithValid,
+    "bound_tag_valid": BoundTagWithValid,
+    "pt_bool_valid": SpatialPointBoolWithValid,
+    "reference_integer": ReferenceInteger,
+    "reference_tag_float": ReferenceTagFloat,
+    "compartment_proofread_status_strategy": CompartmentProofreadStatusStrategy,
+    "reference_tag_with_confidence": ReferenceTagWithConfidence,
 }
 
 
