@@ -2,17 +2,17 @@ import logging
 
 from flask import Blueprint, Flask, jsonify, redirect, url_for
 from flask_restx import Api
+from flask_cors import CORS
 
 from emannotationschemas.blueprint_app import api_bp
 from emannotationschemas.config import configure_app
 from emannotationschemas.utils import get_instance_folder_path
 from emannotationschemas.views import views_bp
 
-__version__ = "5.8.0"
+__version__ = "5.23.0"
 
 
 def create_app(test_config=None):
-
     # Define the Flask Object
     app = Flask(
         __name__,
@@ -20,6 +20,7 @@ def create_app(test_config=None):
         static_url_path="/schema/static",
         instance_relative_config=True,
     )
+    CORS(app, expose_headers="WWW-Authenticate")
 
     logging.basicConfig(level=logging.DEBUG)
 
