@@ -19,6 +19,23 @@ class MetaDataTypes(Enum):
     SUPERVOXEL_ID = "supervoxel_id"
 
 
+class EMBaseSchema(mm.Schema):
+    """Base schema that enforces consistent handling of optional fields"""
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        for field_name, field in self.fields.items():
+            if not field.required:
+                field.allow_none = True
+                if isinstance(field, mm.fields.Nested):
+                    nested_schema = field.schema
+                    if isinstance(nested_schema, mm.Schema):
+                        for nested_field in nested_schema.fields.values():
+                            if not nested_field.required:
+                                nested_field.allow_none = True
+
+
 class NumericField(mm.fields.Int):
     def _jsonschema_type_mapping(self):
         return {
@@ -81,7 +98,7 @@ class IdSchema(mm.Schema):
     oid = mm.fields.Int(description="identifier for annotation, unique in type")
 
 
-class AnnotationSchema(mm.Schema):
+class AnnotationSchema(EMBaseSchema):
     class Meta:
         unknown = INCLUDE
 
@@ -120,7 +137,7 @@ class ReferenceTagAnnotation(ReferenceAnnotation, TagAnnotation):
     """A tag attached to another annotation"""
 
 
-class SpatialPoint(mm.Schema):
+class SpatialPoint(EMBaseSchema):
     """a position in the segmented volume"""
 
     position = PostGISField(
@@ -134,9 +151,9 @@ class SpatialPoint(mm.Schema):
     @mm.post_load
     def transform_position(self, data, **kwargs):
         if self.context.get("postgis", False):
-            data[
-                "position"
-            ] = f'POINTZ({data["position"][0]} {data["position"][1]} {data["position"][2]})'
+            data["position"] = (
+                f"POINTZ({data['position'][0]} {data['position'][1]} {data['position'][2]})"
+            )
 
         return data
 
@@ -190,3 +207,21 @@ class RepresentativePoint(AnnotationSchema):
         required=True,
         description="the point to be used for attaching objects to the dynamic segmentation",
     )
+
+
+class ReferenceInteger(ReferenceAnnotation):
+    """Reference annotation with an integer value"""
+
+    value = mm.fields.Int(
+        required=True,
+        description="Integer value to be attached to the annotation",
+    )
+
+
+class ReferenceTagWithConfidence(ReferenceAnnotation):
+    """Reference annotation with a float value describing confidence in the tag"""
+
+    confidence = mm.fields.Float(
+        required=True,
+        description="Confidence value to be attached to the annotation",
+    )
